@@ -37,9 +37,35 @@ if sys.version_info < (3,):
     COLUMN_TYPES = [type for type in COLUMN_TYPES if type != "boolean"]
 
 
-def get_countries():
-    """A Pandas DataFrame with the world countries (from the world bank data)"""
-    return pd.read_csv(find_package_file("samples/countries.csv"))
+def get_countries(html=True):
+    """A Pandas DataFrame with the world countries (from the world bank data)
+    Flags are loaded from https://flagpedia.net/"""
+    df = pd.read_csv(find_package_file("samples/countries.csv"))
+    df = df.rename(columns={"capitalCity": "capital", "name": "country"})
+    df["iso2Code"] = df["iso2Code"].fillna("NA")  # Namibia
+    df = df.set_index("iso2Code")[
+        ["region", "country", "capital", "longitude", "latitude"]
+    ].dropna()
+    df.index.name = "code"
+
+    if not html:
+        return df
+
+    df["flag"] = [
+        '<a href="https://flagpedia.net/{code}">'
+        '<img src="https://flagpedia.net/data/flags/h80/{code}.webp" '
+        'alt="Flag of {country}"></a>'.format(code=code.lower(), country=country)
+        for code, country in zip(df.index, df["country"])
+    ]
+    df["country"] = [
+        '<a href="https://en.wikipedia.org/wiki/{}">{}</a>'.format(country, country)
+        for country in df["country"]
+    ]
+    df["capital"] = [
+        '<a href="https://en.wikipedia.org/wiki/{}">{}</a>'.format(capital, capital)
+        for capital in df["capital"]
+    ]
+    return df
 
 
 def get_population():
@@ -54,22 +80,30 @@ def get_indicators():
     return pd.read_csv(find_package_file("samples/indicators.csv"))
 
 
-def get_dict_of_test_dfs(N=100, M=100):
-    countries = get_countries()
-    df_complex_index = countries.set_index(["region", "name"])
-    df_complex_index.columns = (
-        pd.DataFrame(
-            {"category": ["code"] * 2 + ["property"] * 2 + ["localisation"] * 4},
-            index=df_complex_index.columns.rename("detail"),
-        )
-        .set_index("category", append=True)
-        .swaplevel()
-        .index
+def get_df_complex_index():
+    df = get_countries()
+    df = df.reset_index().set_index(["region", "country"])
+    df.columns = pd.MultiIndex.from_arrays(
+        [
+            [
+                "code"
+                if col == "code"
+                else "localisation"
+                if col in ["longitude", "latitude"]
+                else "data"
+                for col in df.columns
+            ],
+            df.columns,
+        ],
+        names=["category", "detail"],
     )
+    return df
 
+
+def get_dict_of_test_dfs(N=100, M=100, polars=False):
     NM_values = np.reshape(np.linspace(start=0.0, stop=1.0, num=N * M), (N, M))
 
-    return {
+    test_dfs = {
         "empty": pd.DataFrame(),
         "bool": pd.DataFrame(
             [[True, True, False, False], [True, False, True, False]],
@@ -159,11 +193,9 @@ def get_dict_of_test_dfs(N=100, M=100):
             columns=pd.MultiIndex.from_product((["A", "B"], [1, 2])),
             index=pd.MultiIndex.from_product((["C", "D"], [3, 4])),
         ),
-        "countries": countries,
-        "capital": countries.query('region!="Aggregates"').set_index(
-            ["region", "name"]
-        )[["capitalCity"]],
-        "complex_index": df_complex_index,
+        "countries": get_countries(),
+        "capital": get_countries().set_index(["region", "country"])[["capital"]],
+        "complex_index": get_df_complex_index(),
         "int_float_str": pd.DataFrame(
             {
                 "int": range(N),
@@ -210,8 +242,22 @@ def get_dict_of_test_dfs(N=100, M=100):
         "named_column_index": pd.DataFrame({"a": [1]}).rename_axis("columns", axis=1),
     }
 
+    if polars:
+        import polars as pl
+        import pyarrow as pa
 
-def get_dict_of_test_series():
+        polars_dfs = {}
+        for key in test_dfs:
+            try:
+                polars_dfs[key] = pl.from_pandas(test_dfs[key])
+            except (pa.ArrowInvalid, ValueError):
+                pass
+        return polars_dfs
+
+    return test_dfs
+
+
+def get_dict_of_test_series(polars=False):
     series = {}
     for df_name, df in get_dict_of_test_dfs().items():
         if len(df.columns) > 6:
@@ -221,6 +267,19 @@ def get_dict_of_test_series():
             if not isinstance(df[col], pd.Series):
                 continue
             series["{}.{}".format(df_name, col)] = df[col]
+
+    if polars:
+        import polars as pl
+        import pyarrow as pa
+
+        polars_series = {}
+        for key in series:
+            try:
+                polars_series[key] = pl.from_pandas(series[key])
+            except (pa.ArrowInvalid, ValueError):
+                pass
+        return polars_series
+
     return series
 
 
@@ -250,7 +309,7 @@ def generate_random_series(rows, type):
         x.loc[np.random.binomial(n=1, p=0.05, size=rows) == 0] = float("-inf")
         return x
     if type == "str":
-        return get_countries()["name"].sample(n=rows, replace=True)
+        return get_countries()["region"].sample(n=rows, replace=True)
     if type == "categories":
         x = generate_random_series(rows, "str")
         return pd.Series(x, dtype="category")
